@@ -1076,10 +1076,12 @@ text (technically, this shouldn't happen)."
             (unless (s-blank? (weechat-handle-color-codes prefix))
               (let ((colorized-prefix (weechat-handle-color-codes prefix)))
                 (insert (if (and (integerp weechat-max-nick-length)
-                                 (> weechat-max-nick-length 0))
-                            (substring colorized-prefix 0
-                                       (min (length colorized-prefix)
-                                            weechat-max-nick-length))
+                                 (> weechat-max-nick-length 0)
+                                 (> (length colorized-prefix) weechat-max-nick-length))
+                            (store-substring
+                             (substring colorized-prefix 0 weechat-max-nick-length)
+                             (1- weechat-max-nick-length)
+                             ?\x2026)
                           colorized-prefix)))
               (when (or (eq line-type :irc/privmsg)
                         (not line-type))
@@ -1694,7 +1696,9 @@ called with prefix (\\[universal-argument]), otherwise only monitored buffers."
        (weechat-monitor-buffer weechat-buffer-ptr)))))
 
 (defun weechat-re-monitor-buffers ()
-  (when weechat-auto-reconnect-buffers
+  (interactive)
+  (when (or weechat-auto-reconnect-buffers
+            (interactive-p))
     (maphash (lambda (_ hash)
                (let ((buffer (and (gethash :emacs/buffer hash)
                                   (get-buffer (gethash :emacs/buffer hash)))))
@@ -1739,6 +1743,11 @@ called with prefix (\\[universal-argument]), otherwise only monitored buffers."
               (weechat-monitor-buffer buffer-ptr nil))
           (weechat-warn "Couldn't monitor channel '%s'.  Not found." channel))))))
 
+(defun weechat-monitor-all-buffers ()
+  (interactive)
+  (let ((weechat-auto-monitor-buffers  t))
+    (weechat-auto-monitor)))
+
 
 (add-hook 'weechat-connect-hook 'weechat-auto-monitor 'append)
 
